==> haskell-simple-sendfile-0.2.32-188-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 simple-sendfile
version:              0.2.32
visibility:           public
id:                   simple-sendfile-0.2.32-Kf3PZ1BHGq3mIriiP5NgZ
key:                  simple-sendfile-0.2.32-Kf3PZ1BHGq3mIriiP5NgZ
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.

category:             Network
abi:                  cfe7af330e39d4cdd63009cd17830213
exposed:              True
exposed-modules:      Network.Sendfile System.Linux.Sendfile
hidden-modules:       Network.Sendfile.Types Network.Sendfile.Linux
import-dirs:          /usr/lib/ghc-9.6.6/site-local/simple-sendfile-0.2.32
library-dirs:         /usr/lib/ghc-9.6.6/site-local/simple-sendfile-0.2.32
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/simple-sendfile-0.2.32
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-simple-sendfile
hs-libraries:         HSsimple-sendfile-0.2.32-Kf3PZ1BHGq3mIriiP5NgZ
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    network-3.1.4.0-8n0F06kM1hW6KWRJNaBKOe unix-2.8.4.0

haddock-interfaces:
    /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock

haddock-html:         /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-simple-sendfile-0.2.32-189-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-simple-sendfile.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 simple-sendfile
version:              0.2.32
visibility:           public
id:                   simple-sendfile-0.2.32-JPaaq7o1SU0xatHlb8xiw
key:                  simple-sendfile-0.2.32-JPaaq7o1SU0xatHlb8xiw
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
synopsis:             Cross platform library for the sendfile system call
description:
    Cross platform library for the sendfile system call.
    This library tries to call minimum system calls which
    are the bottleneck of web servers.

category:             Network
abi:                  51c66d18a8f3d1a9e2c505748bc44af3
exposed:              True
exposed-modules:      Network.Sendfile System.Linux.Sendfile
hidden-modules:       Network.Sendfile.Types Network.Sendfile.Linux
import-dirs:          /usr/lib/ghc-9.6.6/site-local/simple-sendfile-0.2.32
library-dirs:         /usr/lib/ghc-9.6.6/site-local/simple-sendfile-0.2.32
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/simple-sendfile-0.2.32
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-simple-sendfile
hs-libraries:         HSsimple-sendfile-0.2.32-JPaaq7o1SU0xatHlb8xiw
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    network-3.1.4.0-JRitsFhJ8rKGUNW13KrLgQ unix-2.8.4.0

haddock-interfaces:
    /usr/share/doc/haskell-simple-sendfile/html/simple-sendfile.haddock

haddock-html:         /usr/share/doc/haskell-simple-sendfile/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
